
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */

#ifndef VNC_CONNECTION_ENUMS_H
#define VNC_CONNECTION_ENUMS_H

#include <glib-object.h>
G_BEGIN_DECLS

/* --- vncconnection.h --- */
#define VNC_TYPE_CONNECTION_ENCODING vnc_connection_encoding_get_type()
GType vnc_connection_encoding_get_type (void);
#define VNC_TYPE_CONNECTION_AUTH vnc_connection_auth_get_type()
GType vnc_connection_auth_get_type (void);
#define VNC_TYPE_CONNECTION_AUTH_VENCRYPT vnc_connection_auth_vencrypt_get_type()
GType vnc_connection_auth_vencrypt_get_type (void);
#define VNC_TYPE_CONNECTION_CREDENTIAL vnc_connection_credential_get_type()
GType vnc_connection_credential_get_type (void);
#define VNC_TYPE_CONNECTION_POWER_ACTION vnc_connection_power_action_get_type()
GType vnc_connection_power_action_get_type (void);
#define VNC_TYPE_CONNECTION_RESIZE_STATUS vnc_connection_resize_status_get_type()
GType vnc_connection_resize_status_get_type (void);
G_END_DECLS

#endif /* VNC_CONNECTION_ENUMS_H */

/* Generated data ends here */

