
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */

#ifndef VNC_DISPLAY_ENUMS_H
#define VNC_DISPLAY_ENUMS_H

#include <glib-object.h>
G_BEGIN_DECLS

/* --- vncdisplay.h --- */
#define VNC_TYPE_DISPLAY_CREDENTIAL vnc_display_credential_get_type()
GType vnc_display_credential_get_type (void);
#define VNC_TYPE_DISPLAY_KEY_EVENT vnc_display_key_event_get_type()
GType vnc_display_key_event_get_type (void);
#define VNC_TYPE_DISPLAY_DEPTH_COLOR vnc_display_depth_color_get_type()
GType vnc_display_depth_color_get_type (void);
G_END_DECLS

#endif /* VNC_DISPLAY_ENUMS_H */

/* Generated data ends here */

